pilot = {}
pilot.__index = pilot

function pilot.create(health, x, y, xVel, yVel)

	local p = {}
	p.img = {
		straight = image["player_straight"],
		right1 = image["player_right1"],
		right2 = image["player_right2"],
		right3 = image["player_right3"],
		left1 = image["player_left1"],
		left2 = image["player_left2"],
		left3 = image["player_left3"],
	}

	p.x = x
	p.y = y
	p.r = 20
	p.x_vel = xVel
	p.y_vel = yVel
	p.tilt = 0
	p.tiltMax = 8
	p.gunPos = {}
	p.gunPos[1] = {x = p.x - 10, y = p.y}
	p.gunPos[2] = {x = p.x + 10, y = p.y}
	p.booster_smallAnim = newAnimation(image["booster_flare_small"],32,32,0.2,2)
	p.booster_bigAnim = newAnimation(image["booster_flare_big"],32,32,0.2,2)

	return setmetatable(p, {__index = pilot})

end

function pilot:update(dt)

	self:wallCollisionCheck()
	self:updateGunPos()
	self.booster_smallAnim:update(dt)
	self.booster_bigAnim:update(dt)
	
	

	if love.keyboard.isDown("right") then
		self.x = self.x + self.x_vel * dt
		self:tiltTo("right", dt)
	end
	if love.keyboard.isDown("left") then
		self.x = self.x - self.x_vel * dt
		self:tiltTo("left", dt)
	end
	if love.keyboard.isDown("up") then
		self.y = self.y - self.y_vel * dt
	end
	if love.keyboard.isDown("down") then
		self.y = self.y + self.y_vel * dt
	end
	if (not love.keyboard.isDown("left") and not love.keyboard.isDown("right"))
	  or (love.keyboard.isDown("left") and love.keyboard.isDown("right")) then
	  	self:tiltTo("straight", dt)
	end


end

function pilot:draw()

	if love.keyboard.isDown("up") then
		self.booster_bigAnim:draw(self.x - 16, self.y + 28)
	else
		self.booster_smallAnim:draw(self.x - 16, self.y + 28)
	end

	if self.tilt == 0 then
		love.graphics.draw(self.img.straight, self.x, self.y,0,1,1,32,32)

	elseif self.tilt > 0 and self.tilt < self.tiltMax/2 then
		love.graphics.draw(self.img.right1, self.x, self.y,0,1,1,32,32)

	elseif self.tilt >= self.tiltMax/2 and self.tilt < self.tiltMax then
		love.graphics.draw(self.img.right2, self.x, self.y,0,1,1,32,32)

	elseif self.tilt >= self.tiltMax then
		love.graphics.draw(self.img.right3, self.x, self.y,0,1,1,32,32)

	elseif self.tilt < 0 and self.tilt > -self.tiltMax/2  then
		love.graphics.draw(self.img.left1, self.x, self.y,0,1,1,32,32)

	elseif self.tilt <= -self.tiltMax/2 and self.tilt > -self.tiltMax then
		love.graphics.draw(self.img.left2, self.x, self.y,0,1,1,32,32)

	elseif self.tilt <= -self.tiltMax then
		love.graphics.draw(self.img.left3, self.x, self.y,0,1,1,32,32)

	else
		love.graphics.draw(self.img.straight, self.x, self.y,0,1,1,32,32)
	end

	if debug then
		love.graphics.circle("line", self.x, self.y, self.r, 32)
	end

end

function pilot:tiltTo(direction, dt)

	if direction == "right" then

		self.tilt = self.tilt + 50 * dt
		if self.tilt > self.tiltMax then
			self.tilt = self.tiltMax
		end

	elseif direction == "left" then

		self.tilt = self.tilt - 50 * dt
		if self.tilt < -self.tiltMax then
			self.tilt = -self.tiltMax
		end

	elseif direction == "straight" then

		if self.tilt < 0 then
			self.tilt = self.tilt + 50 * dt
			if self.tilt > 0 then 
				self.tilt = 0
			end
		elseif self.tilt > 0 then
			self.tilt = self.tilt - 50 * dt
			if self.tilt < 0 then
				self.tilt = 0
			end
		end

	end

end

function pilot:shoot()

	for i = 1, #self.gunPos do
		--(img, x, y, shape, vel, dmg, faction, angle, radius, width, height)
		bullet.create(image["bullet_1"],self.gunPos[i].x,self.gunPos[i].y,"circle",1000,1,"player",-90,7)
	end

end

function pilot:updateGunPos()
	--====Updating the position of the gun barrels
    if self.tilt == 0 then --straight

		self.gunPos[1] = {x = self.x - 27, y = self.y - 3}
		self.gunPos[2] = {x = self.x + 27, y = self.y - 3}

	elseif self.tilt > 0 and self.tilt < self.tiltMax/2 then --slightly to the right

		self.gunPos[1] = {x = self.x - 19, y = self.y - 3}
		self.gunPos[2] = {x = self.x + 25, y = self.y - 3}

	elseif self.tilt >= self.tiltMax/2 and self.tilt < self.tiltMax then --more to the right

		self.gunPos[1] = {x = self.x - 14, y = self.y - 3}
		self.gunPos[2] = {x = self.x + 23, y = self.y - 3}

	elseif self.tilt >= self.tiltMax then --max right

		self.gunPos[1] = {x = self.x - 10, y = self.y - 3}
		self.gunPos[2] = {x = self.x + 20, y = self.y - 3}

	elseif self.tilt < 0 and self.tilt > -self.tiltMax/2  then -- slightly to the left

		self.gunPos[1] = {x = self.x - 25, y = self.y - 3}
		self.gunPos[2] = {x = self.x + 19, y = self.y - 3}

	elseif self.tilt <= -self.tiltMax/2 and self.tilt > -self.tiltMax then -- more to the left

		self.gunPos[1] = {x = self.x - 23, y = self.y - 3}
		self.gunPos[2] = {x = self.x + 14, y = self.y - 3}

	elseif self.tilt <= -self.tiltMax then --max left

		self.gunPos[1] = {x = self.x - 20, y = self.y - 3}
		self.gunPos[2] = {x = self.x + 10, y = self.y - 3}

	else -- just in case.

		self.gunPos[1] = {x = self.x - 27, y = self.y - 3}
		self.gunPos[2] = {x = self.x + 27, y = self.y - 3}

	end
end

function pilot:wallCollisionCheck()
	if self.x + self.r >= screenWidth then
		self.x = screenWidth - self.r
	end
	if self.y + self.r >= screenHeight then
		self.y = screenHeight - self.r
	end
	if self.y - self.r <= 0 then
		self.y = self.r
	end
	if self.x - self.r <= 0 then
		self.x = self.r
	end
end




